import { 
  select, 
  scaleLinear, 
  extent,
  axisLeft,
  axisBottom
} from 'd3';

export const ScatterPlot =(selection, props)=>{
const{innerWidth,innerHeight,circleRadius,
    data,colorScale,colorValue,selectedArtist}=props;
 
 
  const xValue = d => d.year;
  const xAxisLabel = 'Year';

  const yValue = d => d.gdp;
  const yAxisLabel = 'GDP (In Percent)';
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
    
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const xAxis = axisBottom(xScale)
    .ticks(10)
    .tickSize(-innerHeight)
    .tickPadding(10);
  
  const xAxisG = selection.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 65)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(5);
  
  const yAxisG = selection.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -55)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const points = selection.selectAll('.artist').data(data)
  const pointsEnter = points
    .enter().append('circle')
      .attr('class', 'artist')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
    .attr('fill', d => colorScale(d.country));
   points.merge(pointsEnter)
      .attr('opacity', d =>
        (!selectedArtist || d.country === selectedArtist) ? 1 : 0.05);
};

/*
csv('https://vizhub.com/MukundKhandelwal/datasets/us_scatterplot.csv')
  .then(data => {
    data.forEach(d => {
      d.year = +d.year;
      d.revenue = +d.revenue;
      d.expenditure = +d.expenditure;
      d.gdp = +d.gdp;
      d.debt = +d.debt;  
    });
    render(data);
  });*/