import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleOrdinal,
  schemeSet2,
  scaleTime
} from 'd3';

import { colorLegend } from './colorLegend';
import { dataload } from './dataload';
import { ScatterPlot } from './ScatterPlot';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');


var artists;
var selectedArtist;
var data;

const margin = { top: 60, right: 40, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
const g = svg.append('g')
  .attr('transform', `translate(${margin.left},${margin.top})`);
const leg = svg.append('g')
  .attr('transform', `translate(20, 70)`);

const title = 'GDP Variation: USA and Germany';
svg.append('text')
    .attr('class', 'title')
    .attr('x', (width + margin.left) / 2)
    .attr('y', 45)
    .text(title);

/*
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15)
    .tickFormat(format("d"));
    
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);*/

 
const onClick = d => {selectedArtist = d;
  render();
};

//data loading concept used from Nick Lima
dataload().then(processedData => {
  data = processedData;
  artists = [...new Set(data.map(d => d.country))];


const colorScale = scaleOrdinal();
const colorValue = d => d.country;

const render = () => {
  colorScale.domain(artists).range(schemeSet2); 
  
  leg.call(colorLegend, {
    colorScale,
    circleRadius: 8.5,
    spacing: 21,
    textOffset: 12,
    backgroundRectWidth: 135,
    onClick,
    selectedArtist
  });
  
  g.call(ScatterPlot, {data,title,
    colorScale,colorValue, circleRadius: 3.5,
    selectedArtist,innerWidth,
    innerHeight});
};
 